**Example 1: 导出漏洞影响主机列表**



Input: 

```
tccli cwp ExportVulEffectHostList --cli-unfold-argument  \
    --VulId 100435
```

Output: 
```
{
    "Response": {
        "DownloadUrl": "xx",
        "RequestId": "xx",
        "TaskId": "xx"
    }
}
```

